# Import required libraries
import telebot 
from telebot import types  

bot = telebot.TeleBot('TOKEN')

# Product prices in stars
PRICES = {
    '10 Stars': 10,   # $1.00 - Entry level package
    '50 Stars': 45,   # $4.50 - Medium package with 10% discount
    '100 Stars': 80,  # $8.00 - Large package with 20% discount
    '500 Stars': 350  # $35.00 - Bulk package with 30% discount
}

# Handler for /start command - Then the bot will send amount stars to purchase
@bot.message_handler(commands=['start'])
def send_welcome(message):
    # Create a custom keyboard with 2 buttons per row
    markup = types.ReplyKeyboardMarkup(row_width=2)
    # Generate buttons for each product in our PRICES dictionary
    buttons = [types.KeyboardButton(product) for product in PRICES.keys()]
    # Add all buttons to the markup
    markup.add(*buttons)
    
    # Send welcome message with the custom keyboard
    bot.reply_to(message, 
                 "Welcome to Stars Payment Bot!\nPlease select amount of stars to purchase:",
                 reply_markup=markup)

# Handler for when user selects a product from the keyboard
@bot.message_handler(func=lambda message: message.text in PRICES.keys())
def handle_product_selection(message):
    # Get selected product and its price
    product = message.text
    price = PRICES[product]
    
    # Create invoice with product details
    prices = [types.LabeledPrice(label=product, amount=price)]
    
    # Send payment invoice to user
    bot.send_invoice(
        message.chat.id,  # Chat ID to send invoice to
        title=f"Purchase {product}",  # Title of the invoice
        description=f"Buy {product} for your account",  # Description shown on invoice
        provider_token='',  # Payment provider token (empty for testing)
        currency='XTR',  # Currency code
        prices=prices,  # List of prices (we only have one item)
        start_parameter='stars-payment',  # Deep-linking parameter
        invoice_payload=product  # Payload to identify the product after payment
    )

# Pre-checkout handler - Called before payment is completed
@bot.pre_checkout_query_handler(func=lambda query: True)
def process_pre_checkout_query(pre_checkout_query):
    bot.answer_pre_checkout_query(pre_checkout_query.id, ok=True)

# Handler for successful payments
@bot.message_handler(content_types=['successful_payment'])
def handle_successful_payment(message):
    # Get the product that was purchased from the invoice payload
    product = message.successful_payment.invoice_payload
    bot.reply_to(message, 
                 f"Payment for {product} successful!")
bot.polling()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This is a simple echo bot using decorators and webhook with fastapi
# It echoes any incoming text messages and does not use the polling method.

import logging

import fastapi
import uvicorn

import telebot

API_TOKEN = "TOKEN"

WEBHOOK_HOST = "<ip/domain>"
WEBHOOK_PORT = 8443  # 443, 80, 88 or 8443 (port need to be 'open')
WEBHOOK_LISTEN = "0.0.0.0"  # In some VPS you may need to put here the IP addr

WEBHOOK_SSL_CERT = "./webhook_cert.pem"  # Path to the ssl certificate
WEBHOOK_SSL_PRIV = "./webhook_pkey.pem"  # Path to the ssl private key

# Quick'n'dirty SSL certificate generation:
#
# openssl genrsa -out webhook_pkey.pem 2048
# openssl req -new -x509 -days 3650 -key webhook_pkey.pem -out webhook_cert.pem
#
# When asked for "Common Name (e.g. server FQDN or YOUR name)" you should reply
# with the same value in you put in WEBHOOK_HOST

WEBHOOK_URL_BASE = "https://{}:{}".format(WEBHOOK_HOST, WEBHOOK_PORT)
WEBHOOK_URL_PATH = "/{}/".format(API_TOKEN)

logger = telebot.logger
telebot.logger.setLevel(logging.INFO)

bot = telebot.TeleBot(API_TOKEN)

app = fastapi.FastAPI(docs=None, redoc_url=None)


@app.post(f"/{API_TOKEN}/")
def process_webhook(update: dict):
    """
    Process webhook calls
    """
    if update:
        update = telebot.types.Update.de_json(update)
        bot.process_new_updates([update])
    else:
        return


@bot.message_handler(commands=["help", "start"])
def send_welcome(message):
    """
    Handle '/start' and '/help'
    """
    bot.reply_to(
        message,
        ("Hi there, I am EchoBot.\n" "I am here to echo your kind words back to you."),
    )


@bot.message_handler(func=lambda message: True, content_types=["text"])
def echo_message(message):
    """
    Handle all other messages
    """
    bot.reply_to(message, message.text)


# Remove webhook, it fails sometimes the set if there is a previous webhook
bot.remove_webhook()

# Set webhook
bot.set_webhook(
    url=WEBHOOK_URL_BASE + WEBHOOK_URL_PATH, certificate=open(WEBHOOK_SSL_CERT, "r")
)


uvicorn.run(
    app,
    host=WEBHOOK_LISTEN,
    port=WEBHOOK_PORT,
    ssl_certfile=WEBHOOK_SSL_CERT,
    ssl_keyfile=WEBHOOK_SSL_PRIV,
)
